@@ -33,9 +33,10 @@
 #  define KEMOTICONS_DEPRECATED_NO_EXPORT KEMOTICONS_NO_EXPORT KEMOTICONS_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KEMOTICONS_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KEMOTICONS_NO_DEPRECATED
+#    define KEMOTICONS_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
